@@ -1,7 +1,10 @@
-/* Copyright (C) 2015-2017 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved. */
+/* SPDX-License-Identifier: GPL-2.0
+ *
+ * Copyright (C) 2015-2018 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
+ */
 
-#ifndef CHACHA20POLY1305_H
-#define CHACHA20POLY1305_H
+#ifndef _WG_CHACHA20POLY1305_H
+#define _WG_CHACHA20POLY1305_H
 
 #include <linux/types.h>
 
@@ -20,17 +23,18 @@ void chacha20poly1305_encrypt(u8 *dst, const u8 *src, const size_t src_len,
 			      const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN]);
 
 bool __must_check chacha20poly1305_encrypt_sg(struct scatterlist *dst, struct scatterlist *src, const size_t src_len,
-				 const u8 *ad, const size_t ad_len,
-				 const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN],
-				 bool have_simd);
+					      const u8 *ad, const size_t ad_len,
+					      const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN],
+					      bool have_simd);
 
 bool __must_check chacha20poly1305_decrypt(u8 *dst, const u8 *src, const size_t src_len,
-			      const u8 *ad, const size_t ad_len,
-			      const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN]);
+					   const u8 *ad, const size_t ad_len,
+					   const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN]);
 
 bool __must_check chacha20poly1305_decrypt_sg(struct scatterlist *dst, struct scatterlist *src, const size_t src_len,
-				 const u8 *ad, const size_t ad_len,
-				 const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN]);
+					      const u8 *ad, const size_t ad_len,
+					      const u64 nonce, const u8 key[CHACHA20POLY1305_KEYLEN],
+					      bool have_simd);
 
 void xchacha20poly1305_encrypt(u8 *dst, const u8 *src, const size_t src_len,
 			       const u8 *ad, const size_t ad_len,
@@ -38,9 +42,9 @@ void xchacha20poly1305_encrypt(u8 *dst, const u8 *src, const size_t src_len,
 			       const u8 key[CHACHA20POLY1305_KEYLEN]);
 
 bool __must_check xchacha20poly1305_decrypt(u8 *dst, const u8 *src, const size_t src_len,
-			       const u8 *ad, const size_t ad_len,
-			       const u8 nonce[XCHACHA20POLY1305_NONCELEN],
-			       const u8 key[CHACHA20POLY1305_KEYLEN]);
+					    const u8 *ad, const size_t ad_len,
+					    const u8 nonce[XCHACHA20POLY1305_NONCELEN],
+					    const u8 key[CHACHA20POLY1305_KEYLEN]);
 
 #if defined(CONFIG_X86_64)
 #include <linux/version.h>
@@ -54,7 +58,7 @@ bool __must_check xchacha20poly1305_decrypt(u8 *dst, const u8 *src, const size_t
 static inline bool chacha20poly1305_init_simd(void)
 {
 	bool have_simd = false;
-#if defined(CONFIG_X86_64)
+#if defined(CONFIG_X86_64) && !defined(CONFIG_UML)
 	have_simd = irq_fpu_usable();
 	if (have_simd)
 		kernel_fpu_begin();
@@ -72,7 +76,7 @@ static inline bool chacha20poly1305_init_simd(void)
 
 static inline void chacha20poly1305_deinit_simd(bool was_on)
 {
-#if defined(CONFIG_X86_64)
+#if defined(CONFIG_X86_64) && !defined(CONFIG_UML)
 	if (was_on)
 		kernel_fpu_end();
 #elif IS_ENABLED(CONFIG_KERNEL_MODE_NEON)
@@ -85,4 +89,4 @@ static inline void chacha20poly1305_deinit_simd(bool was_on)
 bool chacha20poly1305_selftest(void);
 #endif
 
-#endif
+#endif /* _WG_CHACHA20POLY1305_H */
